# Generated by Django 3.2.12 on 2022-04-04 15:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0154_alter_systemwideenterpriseuserroleassignment_unique_together'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomeruser',
            name='is_relinkable',
            field=models.BooleanField(default=True, help_text='When set to False, the user cannot be relinked to the enterprise.'),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomeruser',
            name='is_relinkable',
            field=models.BooleanField(default=True, help_text='When set to False, the user cannot be relinked to the enterprise.'),
        ),
    ]
