# Generated by Django 3.2.23 on 2023-11-30 18:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0194_auto_20231013_1359'),
    ]

    operations = [
        migrations.AddField(
            model_name='enterprisecustomerssoconfiguration',
            name='marked_authorized',
            field=models.BooleanField(blank=True, default=False, help_text='Whether admin has indicated the service provider metadata was uploaded.', null=True),
        ),
        migrations.AddField(
            model_name='historicalenterprisecustomerssoconfiguration',
            name='marked_authorized',
            field=models.BooleanField(blank=True, default=False, help_text='Whether admin has indicated the service provider metadata was uploaded.', null=True),
        ),
    ]
