# Generated by Django 3.2.15 on 2022-10-31 18:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cornerstone', '0023_auto_20221021_0159'),
    ]

    operations = [
        migrations.AddField(
            model_name='cornerstoneenterprisecustomerconfiguration',
            name='deleted_at',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='historicalcornerstoneenterprisecustomerconfiguration',
            name='deleted_at',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
