# Generated by Django 2.2.15 on 2020-10-02 15:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('moodle', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='MoodleLearnerDataTransmissionAudit',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('moodle_user_email', models.EmailField(help_text='The learner`s Moodle email. This must match the email on edX', max_length=255)),
                ('enterprise_course_enrollment_id', models.PositiveIntegerField(db_index=True)),
                ('course_id', models.CharField(max_length=255)),
                ('grade', models.DecimalField(blank=True, decimal_places=2, max_digits=3, null=True)),
                ('total_hours', models.FloatField(blank=True, null=True)),
                ('course_completed', models.BooleanField(default=True, help_text="The learner's course completion status transmitted to Moodle.")),
                ('completed_timestamp', models.CharField(help_text='Represents the Moodle representation of a timestamp: yyyy-mm-dd, which is always 10 characters.', max_length=10)),
                ('status', models.CharField(max_length=100)),
                ('error_message', models.TextField(blank=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
            ],
        ),
    ]
